@@ -1,11 +1,12 @@
 package App::Oozie::Deploy::Template;
-$App::Oozie::Deploy::Template::VERSION = '0.007';
+$App::Oozie::Deploy::Template::VERSION = '0.008';
 use 5.010;
 use strict;
 use warnings;
 use namespace::autoclean -except => [qw/_options_data _options_config/];
 
 use App::Oozie::Types::Common qw( IsDir );
+use App::Oozie::Util::Misc qw( resolve_tmp_dir );
 use App::Oozie::Constants qw( TEMPLATE_DEFINE_VAR );
 
 use Config::Properties;
@@ -16,7 +17,7 @@ use File::Path qw(
     remove_tree
 );
 use File::Spec;
-use File::Temp qw( tempfile );
+use File::Temp ();
 use Hash::Flatten ();
 use IPC::Cmd ();
 use Moo;
@@ -508,7 +509,7 @@ sub _pre_process_ttconfig_into_tempfile {
     my $opt    = shift || {};
     my $logger = $self->logger;
 
-    my($fh_tmp_cfg, $tmp_cfg_file) = tempfile();
+    my($fh_tmp_cfg, $tmp_cfg_file) = File::Temp::tempfile( undef, DIR => resolve_tmp_dir() );
 
     my $file = File::Spec->catfile( $self->ttlib_base_dir, 'ttree.cfg' );
     open my $FH, '<', $file or die "Failed to read $file: $!";
@@ -554,7 +555,7 @@ App::Oozie::Deploy::Template
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
