@@ -1,5 +1,5 @@
 package App::Oozie::Util::Misc;
-$App::Oozie::Util::Misc::VERSION = '0.007';
+$App::Oozie::Util::Misc::VERSION = '0.008';
 use 5.010;
 use strict;
 use warnings;
@@ -7,10 +7,21 @@ use parent qw( Exporter );
 
 our @EXPORT_OK = qw(
     remove_newline
+    resolve_tmp_dir
 );
 
 sub remove_newline { my $s = shift; $s =~ s{\n+}{ }xmsg; $s }
 
+sub resolve_tmp_dir {
+    # Wokaround "/tmp is an existing symbolic link" error.
+    # Happens in EMR for example.
+    #
+    my $tmp = $ENV{TMPDIR} || $ENV{TMP} || '/tmp';
+    return $tmp if ! -l $tmp;
+    my $real = readlink $tmp;
+    return $real;
+}
+
 1;
 
 __END__
@@ -25,7 +36,7 @@ App::Oozie::Util::Misc
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -43,6 +54,8 @@ App::Oozie::Util::Misc - Miscellaneous utility functions
 
 =head2 remove_newline
 
+=head2 resolve_tmp_dir
+
 =head1 SEE ALSO
 
 L<App::Oozie>.
